## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           spyder
Version:        6.1.0~a2
Release:        %autorelease -b0
Summary:        Scientific Python Development Environment

%global forgeurl https://github.com/spyder-ide/spyder/
%global tag v%{version_no_tilde %{quote:%nil}}
%forgemeta

# Spyder is licensed under MIT with the exception of the following
# code, which is licensed BSD-3-Clause.
#
# spyder/widgets/calltip.py
# spyder/utils/introspection/module_completion.py
# spyder/plugins/editor/utils/kill_ring.py
# spyder/plugins/help/utils/conf.py
# spyder/plugins/help/utils/sphinxify.py
# spyder/plugins/help/utils/js/collapse_sections.js
License:        MIT AND BSD-3-Clause
URL:            https://www.spyder-ide.org/
Source:         %forgesource

BuildArch:      noarch
# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch:    %{ix86}
# Taken from pyqtwebengine's spec file. Since we require this, we need
# to follow suit.
# Add 'noarch' as per packaging guidelines
# https://docs.fedoraproject.org/en-US/packaging-guidelines/#_noarch_with_unported_dependencies
ExclusiveArch:  %{qt5_qtwebengine_arches} noarch

BuildRequires:  python3-devel

BuildRequires:  dos2unix

BuildRequires:  desktop-file-utils
# Still required by guidelines for now since Fedora uses appstream-builder
# (https://pagure.io/packaging-committee/issue/1053):
BuildRequires:  libappstream-glib
# Matches what gnome-software and others use:
BuildRequires:  appstream

%global appname org.spyder_ide.spyder

%global _description %{expand:
Spyder is a powerful scientific environment written in Python, for Python, and
designed by and for scientists, engineers and data analysts. It offers a unique
combination of the advanced editing, analysis, debugging, and profiling
functionality of a comprehensive development tool with the data exploration,
interactive execution, deep inspection, and beautiful visualization
capabilities of a scientific package.

Beyond its many built-in features, its abilities can be extended even further
via its plugin system and API. Furthermore, Spyder can also be used as a PyQt5
extension library, allowing you to build upon its functionality and embed its
components, such as the interactive console, in your own software.}

%description %_description


%package -n python3-spyder
Summary:    %{summary}

# For %%{_datadir}/icons
Requires:       hicolor-icon-theme
# Unbundled from spyder/plugins/help/utils/js/mathjax
Requires:       mathjax
# Required for the plugins (but not for building Spyder)
Requires:       python3-pylint
Requires:       python3-pylint-venv

%description -n python3-spyder %_description


%prep
%forgeautosetup -p1

# Remove bundled external dependencies
rm -rvf external-deps/ spyder/plugins/help/utils/js/mathjax

# Fix DOS/CRNL line endings in files that may be installed
find . -type f \( \
    -name '*.rst' -o -name '*.md' -o -name '*.py' -o -name '*.css' \
    \) -exec dos2unix --keepdate '{}' '+'

%dnl # Drop dependency on linters (pylint and pylint-venv)
%dnl sed -r \
%dnl     -e '/pylint>.*/d' \
%dnl     -e '/pylint-venv>.*/d' \
%dnl     -i setup.py
%dnl 
%dnl # Don't show warning regarding newer version
%dnl sed -r -i "s|(PYLINT_REQVER.*),<.*'|\1'|" spyder/dependencies.py

# Drop lower bound on `bcrypt`
sed -r \
    -e 's/(bcrypt)[>=<]+[0-9.]+/\1/' \
    -i setup.py

# Also silence internal version check
sed -r \
    -e "s/(BCRYPT_REQVER = )['\"].*['\"]/\1'>=4.0.0'/" \
    -i spyder/dependencies.py


%generate_buildrequires
%pyproject_buildrequires


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files -l spyder

desktop-file-install --dir=%{buildroot}%{_datadir}/applications scripts/spyder.desktop

# cleanup
rm -rvf %{buildroot}%{_bindir}/spyder_win_post_install.py

# replace bundled mathjax with a symlink to the system mathjax
ln -s %{_datadir}/javascript/mathjax/ \
    %{buildroot}%{python3_sitelib}/spyder/plugins/help/utils/js/mathjax

# provide spyder3 as symlink to spyder binary for continuity
ln -s spyder %{buildroot}%{_bindir}/spyder3


%check
# Still required by guidelines for now since Fedora uses appstream-builder
# (https://pagure.io/packaging-committee/issue/1053):
appstream-util validate-relax --nonet \
    %{buildroot}/%{_metainfodir}/%{appname}.appdata.xml
# Matches what gnome-software and others use:
appstreamcli validate --no-net --explain \
    %{buildroot}/%{_metainfodir}/%{appname}.appdata.xml


%files -n python3-spyder -f %{pyproject_files}
%doc CHANGELOG.md
%doc README.md

# A backed-up bundled mathjax directory from a previous upgrade (from Fedora 34
# or older) may be present; if so, we should continue to own it.
%ghost %{python3_sitelib}/spyder/plugins/help/utils/js/mathjax.rpmmoved
%{python3_sitelib}/spyder/plugins/help/utils/js/mathjax

%{_bindir}/spyder
%{_bindir}/spyder3

%{_metainfodir}/%{appname}.appdata.xml
%{_datadir}/applications/spyder.desktop
%{_datadir}/icons/spyder.png


%changelog
## START: Generated by rpmautospec
* Wed Apr 23 2025 Sandro <devel@penguinpee.nl> - 6.1.0~a2-0
- Uncommitted changes

* Fri Apr 04 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 6.0.5-2
- Remove the pretrans scriptlet that provided an upgrade path from Fedora
  34 and earlier

* Fri Mar 28 2025 Sandro <devel@penguinpee.nl> - 6.0.5-1
- Update to 6.0.5

* Sun Feb 09 2025 Sandro <devel@penguinpee.nl> - 6.0.4-2
- Migrate to SPDX License

* Sat Feb 08 2025 Sandro <devel@penguinpee.nl> - 6.0.4-1
- Update to 6.0.4 (RHBZ#2344103)

* Sun Jan 19 2025 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Thu Dec 12 2024 Sandro <devel@penguinpee.nl> - 6.0.3-1
- Update to 6.0.3 (RHBZ#2330948)

* Fri Nov 01 2024 Sandro <devel@penguinpee.nl> - 6.0.2-1
- Update to 6.0.2 (RHBZ#2322641)

* Wed Sep 25 2024 Sandro <devel@penguinpee.nl> - 6.0.1-1
- Update to 6.0.1 (RHBZ#2314349)

* Tue Sep 03 2024 Sandro <devel@penguinpee.nl> - 6.0.0-1
- Update to 6.0.0 (RHBZ#2309339)
- Fix RHBZ#2309393

* Tue Aug 27 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 6.0.0~rc2-1
- Update to 6.0.0rc2
- Patch to allow python-lsp-server-1.12.0

* Sat Aug 10 2024 Sandro <devel@penguinpee.nl> - 6.0.0~rc1-1
- Update to 6.0.0rc1

* Mon Jul 22 2024 Sandro <devel@penguinpee.nl> - 6.0.0~b3-1
- Update to 6.0.0b3 (RHBZ#2280901)

* Sat Jul 20 2024 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.0~a5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sat Jun 29 2024 Sandro <devel@penguinpee.nl> - 6.0.0~a5-2
- Rebuild for Python 3.13

* Wed Apr 24 2024 Sandro <devel@penguinpee.nl> - 6.0.0~a5-1
- Update to 6.0.0a5 (RHBZ#2276783)

* Mon Mar 25 2024 Sandro <devel@penguinpee.nl> - 6.0.0~a4-4
- Fix IPython console not starting (RHBZ#2269780)

* Sun Mar 24 2024 Sandro <devel@penguinpee.nl> - 6.0.0~a4-3
- Quench warning regarding newer version

* Sun Mar 24 2024 Sandro <devel@penguinpee.nl> - 6.0.0~a4-2
- Remove dependency version mangling

* Sat Mar 09 2024 Sandro <devel@penguinpee.nl> - 6.0.0~a4-1
- Update to 6.0.0a4 (RHBZ#2106899)

* Tue Jan 30 2024 Sandro <devel@penguinpee.nl> - 6.0.0~a1-17
- Add missing runtime requirement for `pylint_venv`.

* Mon Jan 29 2024 Sandro <devel@penguinpee.nl> - 6.0.0~a1-16
- Fix patching of upper bounds (RHBZ#2260884)

* Sun Jan 28 2024 Sandro <devel@penguinpee.nl> - 6.0.0~a1-15
- Drop upper bound from python-lsp-server

* Sat Jan 27 2024 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.0~a1-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 15 2024 Sandro <devel@penguinpee.nl> - 6.0.0~a1-13
- Fix ExlusiveArch

* Tue Jan 02 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 6.0.0~a1-12
- Assert that the .dist-info directory contains a license file

* Tue Dec 12 2023 Sandro <devel@penguinpee.nl> - 6.0.0~a1-11
- Drop BR on `pylint` and `pylint-venv`

* Tue Nov 14 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 6.0.0~a1-10
- Add a developer id in the AppData

* Mon Nov 13 2023 Sandro <devel@penguinpee.nl> - 6.0.0~a1-9
- Remove upper bound for `qdarkstyle`

* Sat Nov 11 2023 Sandro <devel@penguinpee.nl> - 6.0.0~a1-8
- Drop upper bound on `qtconsole`

* Thu Nov 09 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 6.0.0~a1-7
- Fix deprecated top-level developer_name in AppData XML

* Thu Nov 09 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 6.0.0~a1-6
- Ask appstreamcli to explain validation findings

* Thu Nov 09 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 6.0.0~a1-5
- Correct appstreamcli invocation (--nonet no longer works)

* Tue Nov 07 2023 Sandro <devel@penguinpee.nl> - 6.0.0~a1-4
- Loosen PyLSP upper bound (RHBZ#2248558)

* Tue Oct 10 2023 Sandro <devel@penguinpee.nl> - 6.0.0~a1-3
- Bump upper bound of python-lsp-server to <1.9.0

* Tue Oct 10 2023 Sandro <devel@penguinpee.nl> - 6.0.0~a1-2
- Patch the patches
- Backport patches from master not in v6.0.0a2

* Tue Oct 10 2023 Sandro <devel@penguinpee.nl> - 6.0.0~a1-1
- Update to 6.0.0a1 (RHBZ#2242941)

* Mon Oct 02 2023 Sandro <devel@penguinpee.nl> - 5.4.5-23
- Fix pylint upper bound

* Tue Sep 26 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-22
- Use upstream PR for useless shebangs now that it’s rebased on 5.x

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-21
- Send a PR upstream for useless shebangs, replacing the downstream patch

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-19
- Replace downstream dep. version patch with commit/PR backports

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-18
- Package the changelog and readme files as documentation

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-15
- Add missing explicit BuildRequires on python3-devel

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-14
- Tidy up AppStream metadata handling
- Validate in check, and add a validation with appstreamcli
- Use the _metainfodir macro in paths

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-13
- Simplify fixing DOS line endings

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-11
- Explicitly remove bundled dependencies in prep

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-10
- Drop AppData XML file sed-patch
- It no longer has any effect

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-6
- Make the spyder3 symlink relative

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-5
- Remove obsolete ldconfig_scriptlets macro

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.4.5-4
- Updated description from upstream

* Sun Sep 24 2023 Sandro <devel@penguinpee.nl> - 5.4.5-3
- Drop versioned patch

* Sun Sep 24 2023 Sandro <devel@penguinpee.nl> - 5.4.5-2
- Add ExclusiveArch
- Follow suit since we depend on `pyqtwebengine`

* Sun Sep 24 2023 Sandro <devel@penguinpee.nl> - 5.4.5-1
- Update to 5.4.5 (RHBZ#2220598)

* Sun Sep 24 2023 Sandro <devel@penguinpee.nl> - 5.3.1-10
- Spec file overhaul
- Use forge macros
- Use Python RPM macros
- Restructure spec file
- Clean up obsolete BRs

* Sat Sep 23 2023 Sandro <devel@penguinpee.nl> - 5.3.1-9
- Whitespace changes
- Use spaces NOT tabs (this is Python after all)
- Be consistent with intersection spacing

* Sat Jul 22 2023 Fedora Release Engineering <releng@fedoraproject.org> - 5.3.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Wed Jun 14 2023 Python Maint <python-maint@redhat.com> - 5.3.1-7
- Rebuilt for Python 3.12

* Sat Jan 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 5.3.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Dec 19 2022 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 5.3.1-5
- Drop support for i686

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 5.3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jun 13 2022 Python Maint <python-maint@redhat.com> - 5.3.1-3
- Rebuilt for Python 3.11

* Sat May 28 2022 Mukundan Ragavan <nonamedotc@gmail.com> - 5.3.1-2
- upload v5.3.1 sources

* Sat May 28 2022 Mukundan Ragavan <nonamedotc@gmail.com> - 5.3.1-1
- Update spyder to v5.3.1

* Sat Apr 23 2022 Mukundan Ragavan <nonamedotc@gmail.com> - 5.3.0-2
- relax ipython version; clarify python-lsp-server dep

* Thu Mar 31 2022 Mukundan Ragavan <nonamedotc@gmail.com> - 5.3.0-1
- Update to 5.3.0

* Sat Jan 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sun Jan 16 2022 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 5.2.1-1
- Update to 5.2.1
- Drop upstreamed patch and update relax-versions patch

* Tue Dec 14 2021 Mamoru TASAKA <mtasaka@fedoraproject.org> - 5.1.5-2
- Relax dependency for spyder-kernels for now (bug 2031749)

* Sun Sep 19 2021 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 5.1.5-1
- Update to 5.1.5

* Mon Sep 13 2021 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 5.1.4-1
- Update to 5.1.4

* Sun Sep 05 2021 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 5.1.3-1
- Update to 5.1.3

* Tue Aug 17 2021 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 5.1.1-1
- Update to 5.1.1
- Drop explicit requires in favor of automatic requires

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 4.2.5-2
- Rebuilt for Python 3.10

* Thu Apr 08 2021 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 4.2.5-1
- Update to 4.2.5
- Update appdata filename

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Thu Dec 24 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 4.2.1-1
- Update to 4.2.1

* Mon Sep 14 2020 Ben Beasley <code@musicinmybrain.net> - 4.1.5-2
- Unbundle mathjax (RHBZ #1017213)

* Thu Sep 03 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 4.1.5-1
- Update to 4.1.5

* Mon Aug 03 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 4.1.4-4
- Drop python-sitelib macro usage

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.1.4-3
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.1.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Jul 11 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 4.1.4-1
- Update to 4.1.4

* Tue Jun 23 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 4.1.3-3
- Add BR:python3-setuptools

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 4.1.3-2
- Rebuilt for Python 3.9

* Sat May 09 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 4.1.3-1
- Update to 4.1.3

* Thu May 07 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 4.1.2-1
- Update to 4.1.2
- Minor spec changes

* Sat Feb 29 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.6-5
- Drop pathlib2 as requires

* Fri Jan 31 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.3.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Wed Sep 11 2019 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.6-3
- Drop pep8 as requires

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 3.3.6-2
- Rebuilt for Python 3.8

* Wed Aug 14 2019 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.6-1
- Update to 3.3.6

* Sat Jul 27 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.3.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu Apr 25 2019 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.4-1
- Update to 3.3.4

* Sun Feb 10 2019 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.3-1
- Update to 3.3.3

* Sun Feb 03 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sun Dec 02 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.2-1
- Update to 3.3.2

* Sun Oct 28 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.1-6
- Fix desktop file installation

* Sun Oct 28 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.1-5
- Drop python2 version

* Mon Oct 15 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.1-4
- Drop direct requires on prompt_toolkit (should be pulled through iPython)

* Thu Aug 23 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.1-3
- Fix py2 requires

* Sun Aug 12 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.1-2
- Fix description
- Drop py3 conditional

* Sat Aug 11 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.1-1
- Update to 3.3.1

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jul 10 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.0-2
- Add requires on python-spyder-kernels

* Sat Jul 07 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.3.0-1
- Update to 3.3.0
- Fix appdata file install location

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 3.2.8-3
- Rebuilt for Python 3.7

* Fri Mar 23 2018 Iryna Shcherbina <ishcherb@redhat.com> - 3.2.8-2
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Thu Mar 15 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.8-1
- Update to 3.2.8

* Sat Mar 03 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.7-4
- Add conditional for py2-chardet

* Mon Feb 26 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.7-3
- Update to 3.2.7
- use ldconfig-scriptlets
- fix icon installation
- bump release

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.2.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Jan 19 2018 Mukundan Ragavan <nonamedotc@gmail.com> - 3.2.6-3
- bump release and rebuild

* Thu Jan 18 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.6-2
- change requires from py* to py2* subpackages

* Tue Jan 09 2018 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.6-1
- Update to 3.2.6

* Thu Jan 04 2018 Lumír Balhar <lbalhar@redhat.com> - 3.2.5-3
- Fix directory ownership

* Wed Dec 27 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.5-2
- Add cloudpickle as dependency

* Wed Dec 27 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.5-1
- Update to 3.2.5 (bugfix update)

* Sun Nov 12 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.4-2
- Add requires for python3-rope

* Fri Oct 20 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.4-1
- Update to 3.2.4

* Mon Sep 11 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.3-1
- Update to 3.2.3

* Thu Sep 07 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.2-1
- Update to 3.2.2

* Sat Sep 02 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.1-2
- Fix requires (python- vs python2-)
- Add pycodestyle as requires

* Mon Aug 14 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.2.1-1
- Update to 3.2.1
- Drop the appdata patch in favor of sed fix

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.1.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jul 10 2017 Tomas Hozza <thozza@redhat.com> - 3.1.4-3
- Use RPM macros for building and installing Python2 and Python3 versions of the package
- Provide upgrade path from spyder package (#1469003)

* Thu May 04 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.1.4-2
- Fix requires for python3 subpackage

* Mon Apr 24 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.1.4-1
- Update to 3.1.4
- Install upstream desktop files
- Install appdata file

* Thu Mar 16 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.1.3-2
- Add numpydoc as requires

* Mon Feb 20 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.1.3-1
- Update to 3.1.3

* Thu Jan 26 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.1.2-1
- Update to 3.1.2

* Sun Jan 22 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.1.1-1
- Update to 3.1.1

* Wed Jan 18 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.1.0-2
- Update requires completely

* Wed Jan 18 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.1.0-1
- Update to 3.1.0

* Tue Jan 03 2017 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.0.2-2
- Add dependencies

* Thu Dec 29 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.0.2-1
- Update to 3.0.2

* Tue Sep 20 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.0.0-3.b7
- Update to beta 7

* Sat Sep 03 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.0.0-3.b6
- Update to beta 6

* Thu Aug 11 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.0.0-2.b4
- Fix requires

* Wed Aug 10 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.0.0-1.b4
- Update to 3.0.0 beta 4

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.9-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue Apr 26 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 2.3.9-1
- Update to v2.3.9

* Wed Mar 02 2016 Rex Dieter <rdieter@fedoraproject.org> 2.3.8-3
- (unconditionally) Requires: PyQt4-webkit

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Dec 02 2015 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 2.3.8-1
- Update to 2.3.8

* Thu Nov 12 2015 Kalev Lember <klember@redhat.com> - 2.3.7-5
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Wed Nov 04 2015 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 2.3.7-4
- Fix spyder3 desktop file

* Tue Nov 03 2015 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 2.3.7-3
- Added EL conditionals for requires

* Mon Nov 02 2015 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 2.3.7-2
- Build python3 subpackage

* Tue Oct 06 2015 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 2.3.7-1
- Updated to v2.3.7
- Updated source and package URL
- Removed old version patch

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Aug 07 2014 Radek Novacek <rnovacek@redhat.com> 2.2.4-4
- Remove Requires: qtwebkit as its already pulled by PyQt4

* Wed Jul 30 2014 Radek Novacek <rnovacek@redhat.com> 2.2.4-3
- Add Requires: qtwebkit (#1121360)

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Sep 25 2013 Tomas Hozza <thozza@redhat.com> 2.2.4-1
- new upstream version 2.2.4 (#1010935)
- Spyder failed to start and ended with EOFError (#1010568)

* Fri Aug 16 2013 Radek Novacek <rnovacek@redhat.com> 2.2.2-1
- Update to 2.2.2

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 10 2013 Radek Novacek <rnovacek@redhat.com> 2.2.1-1
- Update to 2.2.1

* Mon May 20 2013 Radek Novacek <rnovacek@redhat.com> 2.2.0-1
- Update to 2.2.0
- Spec cleanup
- Add spyder.png pixmap
- Resolves: #958040

* Mon Mar 11 2013 Radek Novacek <rnovacek@redhat.com> 2.1.13-3
- Fix checking PyQt4 version
- Resolves: #919921

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan 10 2013 Radek Novacek <rnovacek@redhat.com> 2.1.13-1
- Update to 2.1.13

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Feb 06 2012 Radek Novacek <rnovacek@redhat.com> 2.1.6-3
- Require pyflakes >= 0.5.0
- Resolves: #786836

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Jan 02 2012 Radek Novacek <rnovacek@redhat.com> 2.1.6-1
- Update to 2.1.6
- Fix crash with ipython 0.12dev
- Resolves: #770161

* Fri Nov 25 2011 Radek Novacek <rnovacek@redhat.com> 2.1.2-1
- Update to 2.1.2

* Mon Nov 07 2011 Radek Novacek <rnovacek@redhat.com> - 2.1.1-1
- Update to 2.1.1

* Thu Jul 14 2011 Radek Novacek <rnovacek@redhat.com> - 2.0.12-1
- Update to 2.0.12

* Sun May 22 2011 Chen Lei <supercyper@163.com> - 2.0.11-1
- Update to 2.0.11

* Sun Dec 19 2010 Chen Lei <supercyper@163.com> - 2.0.5-1
- Update to 2.0.5

* Wed Dec 08 2010 Chen Lei <supercyper@163.com> - 2.0.3-1
- Update to 2.0.3

* Wed Dec 01 2010 Chen Lei <supercyper@163.com> - 2.0.1-1
- Update to 2.0.1

* Tue Nov 30 2010 Chen Lei <supercyper@163.com> - 2.0.0-1
- Update to 2.0.0 final

* Wed Oct 13 2010 Chen Lei <supercyper@163.com> - 2.0.0-0.2.beta5
- Update to 2.0.0beta5

* Wed Sep 15 2010 Chen Lei <supercyper@163.com> - 2.0.0-0.1.beta3
- Initial rpm build

## END: Generated by rpmautospec
